@@ -53,8 +53,9 @@ fn main() {
     if args.detect_and_exit {
         println!("Terminal: {terminal}");
     } else {
-        // Enable Ansi color processing on Windows; no-op on other platforms.
-        concolor_query::windows::enable_ansi_colors();
+        // Enable Ansi color processing on Windows
+        #[cfg(windows)]
+        anstyle_query::windows::enable_ansi_colors();
 
         let terminal_size = TerminalSize::detect().unwrap_or_default();
         let terminal_size = if let Some(max_columns) = args.columns {
